========================================================
Experimental Buildout extension to provude wheel support
========================================================

To get wheel support in Buildout 2.8 or later, including the buildut
wheel extension::

  [buildout]
  extensions = buildout.wheel
  ...
